.. role:: hidden
    :class: hidden-section


botorch.posteriors
========================================================
.. automodule:: botorch.posteriors


Posterior APIs
-------------------------------------------

Abstract Posterior API
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.posteriors.posterior
    :members:


Posteriors
-------------------------------------------

GPyTorch Posterior
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.posteriors.gpytorch
    :members:

Determinstic Posterior
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.posteriors.deterministic
    :members:

Higher Order GP Posterior
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.posteriors.higher_order
    :members:

Multitask GP Posterior
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.posteriors.multitask
    :members:

Transformed Posterior
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.posteriors.transformed
    :members:
